@@ -17,7 +17,6 @@
 import sys
 import os
 import re
-from calculate.lib.datavars import DataVarsError
 from calculate.lib.cl_template import TemplateFormat
 import hashlib
 
@@ -93,7 +92,8 @@ class backgrounds(TemplateFormat):
         if not force and (width > self.source_width or
                           height > self.source_height):
             return False
-        if ((width == self.source_width and height == self.source_height) and
+        if self.convert != "gfxboot" and (
+            (width == self.source_width and height == self.source_height) and
                 (source.rpartition('.')[2] == target.rpartition('.')[2])):
             with writeFile(target) as sf:
                 sf.write(readFile(source))
@@ -101,19 +101,23 @@ class backgrounds(TemplateFormat):
         if self.chroot_cmd:
             source = self.trim_chroot_path(source)
             target = self.trim_chroot_path(target)
+
+        command = [self.convert_cmd, "-quality", "95",
+                   source, "-resize", "%s^" % res,
+                   "-strip", "-gravity", "center",
+                   "-crop", "%s+0+0" % res]
+        if self.convert == "gfxboot":
+            command.extend(
+                ["-sampling-factor", "2x2",
+                 "-interlace", "none",
+                 "-set", "units", "PixelsPerSecond"])
+        command += [target]
+        if self.chroot_cmd:
             convert = process(self.chroot_cmd, self.chroot_path,
                               self.bash_cmd, "-c",
-                              " ".join([self.convert_cmd, "-quality", "95",
-                              source, "-resize", "%s^" % res,
-                              "-gravity", "center",
-                              "-crop", "%s+0+0" % res,
-                              target]), stderr=STDOUT)
+                              " ".join(command), stderr=STDOUT)
         else:
-            convert = process(self.convert_cmd, "-quality", "95",
-                              source, "-resize", "%s^" % res,
-                              "-gravity", "center",
-                              "-crop", "%s+0+0" % res,
-                              target, stderr=STDOUT)
+            convert = process(*command, stderr=STDOUT)
         convert.write(self.text)
         if convert.success():
             return True
@@ -223,8 +227,10 @@ class backgrounds(TemplateFormat):
                 if only_one:
                     image_fn = pathJoin(workdir, prefix)
                 else:
+                    ext_map = {'gfxboot': 'jpg'}
                     image_fn = pathJoin(workdir, "%s%s.%s" % (
-                        prefix, resolution, self.convert))
+                        prefix, resolution,
+                        ext_map.get(self.convert, self.convert)))
                 if self._create_image(source, image_fn, width, height,
                                       force=self.stretch):
                     if image_fn in removed_files:
